

xtick_font = {
    "family": "DejaVu Sans",
    "size": 10,
    "weight": "bold",
    "alpha": 1.0,
    "zorder": 3,
}

color="#003366"
edgecolor="k"
linewidth=0.5
alpha=0.7

#dir_topo = '/Users/jiachenlu/forSimulationOnly/highRes/'



